@@ -4,6 +4,7 @@ Classes:
 
     Public:
         App
+        WindowManager
     Private:
         _ToggleButton
         _SettingsApp
@@ -22,9 +23,9 @@ Misc variables:
     supported_from
 """
 
-__all__ = ["App"]
+__all__ = ["App", "WindowManager"]
 __author__ = "Alexander Bisland"
-__version__ = "3.3.2"
+__version__ = "3.3.4"
 supported_from = "3.8.1"
 
 from tkinter import Tk, Button, Canvas, PhotoImage, Label, Frame, Entry, Spinbox, Misc, Event
@@ -41,6 +42,22 @@ _HelpAppVar = TypeVar("_HelpAppVar", bound="_HelpApp")
 
 
 class _ToggleButton(Canvas):
+    """Widget Inherting methods from canvas that represents a toggle button
+
+    Functions:
+
+        _ToggleButton.get_state(self: _ToggleButtonVar) -> (int) position of the button - 0 or 1
+
+    Class variables:
+
+        Public:
+            self.master    - total number of variables in the expression (used for table dimensions)
+            self.state = 0 - unsimplified expression
+        Private:
+            self._day      - list of valid symbols that can be used
+            self._night    - debug mode (enables some prints)
+            self._button   - the table (can also get access through __repr__)
+    """
     def __init__(self: _ToggleButtonVar, master: Optional[Misc], command: Optional[Callable] = None,
                  file0: str = "night.gif", file1: str = "day.gif", default: int = 0, *args, **kwargs) -> None:
         super().__init__(master, *args, **kwargs)
@@ -71,6 +88,16 @@ class _ToggleButton(Canvas):
 
 
 class WindowManager:
+    """Static class to open windows based on private classes
+
+    Functions:
+
+        KarnaughMapObject.create_map(tot_input=None, expression=None) -> (bool) success
+        KarnaughMapObject.print(object, file) -> (None)
+        KarnaughMapObject.to_string(object, file) -> (str) reader-friendly table
+        KarnaughMap.get_tot_variables(expression: str) -> (Union[int, None]) total number of variables
+        KarnaughMapObject.solve_map(self: object) -> (str) simplified binary logic representation of map
+    """
     @staticmethod
     def open_credits() -> None:
         credits_window = Tk()
@@ -97,6 +124,21 @@ class WindowManager:
 
 
 class _CreditsApp:
+    """Create Karnaugh Map objects which can be solved and manipulated.
+    Supported characters:
+        Any case is supported
+        or equivalents: |, ||, +, v
+        and equivalents: &, &&, *, ^
+        not equivalents: !, ~, ¬
+
+    Functions:
+
+        (None see tkinter.Canvas for inherited functions)
+
+    Class variables:
+
+        (None see tkinter.Canvas for inherited variables)
+    """
     def __init__(self: _CreditsAppVar, master: Tk) -> None:
         master.title("Credits")
         master.geometry("250x50")
@@ -109,6 +151,44 @@ class _CreditsApp:
 
 
 class _HelpApp:
+    """Create Karnaugh Map objects which can be solved and manipulated.
+    Supported characters:
+        Any case is supported
+        or equivalents: |, ||, +, v
+        and equivalents: &, &&, *, ^
+        not equivalents: !, ~, ¬
+
+    Functions:
+
+        KarnaughMapObject.create_map(tot_input=None, expression=None) -> (bool) success
+        KarnaughMapObject.print(object, file) -> (None)
+        KarnaughMapObject.to_string(object, file) -> (str) reader-friendly table
+        KarnaughMap.get_tot_variables(expression: str) -> (Union[int, None]) total number of variables
+        KarnaughMapObject.solve_map(self: object) -> (str) simplified binary logic representation of map
+
+    GLOBAL static variables:
+
+        SINGLE  - headings for one variable
+        DOUBLE  - headings for two variables
+        TRIPLE  - headings for three variables
+        VALUES  - pairings for a whole table (index=number of variable)
+        LETTERS - letters than can be used
+
+    Class variables:
+
+        self.tot_input = None     - total number of variables in the expression (used for table dimensions)
+        self.expression = None    - unsimplified expression
+        self.valid_symbols = None - list of valid symbols that can be used
+        self.debug = debug        - debug mode (enables some prints)
+        self.table = []           - the table (can also get access through __repr__)
+        self.result = ""          - the simplified expression
+        self.raise_error = True   - whether to raise errors or just print them
+
+    Other data:
+
+        Order of operations: BNAO
+        Only tested up to 4 variables
+    """
     def __init__(self: _HelpAppVar, master: Tk) -> None:
         master.title("Help")
         master.geometry("350x200")
@@ -125,6 +205,44 @@ class _HelpApp:
 
 
 class _SettingsApp:
+    """Create Karnaugh Map objects which can be solved and manipulated.
+    Supported characters:
+        Any case is supported
+        or equivalents: |, ||, +, v
+        and equivalents: &, &&, *, ^
+        not equivalents: !, ~, ¬
+
+    Functions:
+
+        KarnaughMapObject.create_map(tot_input=None, expression=None) -> (bool) success
+        KarnaughMapObject.print(object, file) -> (None)
+        KarnaughMapObject.to_string(object, file) -> (str) reader-friendly table
+        KarnaughMap.get_tot_variables(expression: str) -> (Union[int, None]) total number of variables
+        KarnaughMapObject.solve_map(self: object) -> (str) simplified binary logic representation of map
+
+    GLOBAL static variables:
+
+        SINGLE  - headings for one variable
+        DOUBLE  - headings for two variables
+        TRIPLE  - headings for three variables
+        VALUES  - pairings for a whole table (index=number of variable)
+        LETTERS - letters than can be used
+
+    Class variables:
+
+        self.tot_input = None     - total number of variables in the expression (used for table dimensions)
+        self.expression = None    - unsimplified expression
+        self.valid_symbols = None - list of valid symbols that can be used
+        self.debug = debug        - debug mode (enables some prints)
+        self.table = []           - the table (can also get access through __repr__)
+        self.result = ""          - the simplified expression
+        self.raise_error = True   - whether to raise errors or just print them
+
+    Other data:
+
+        Order of operations: BNAO
+        Only tested up to 4 variables
+    """
     def __init__(self: _SettingsAppVar, master: Tk, main_app: _App) -> None:
         self.master = master
         self.master.title("Settings")
@@ -236,6 +354,44 @@ class _SettingsApp:
 
 
 class App:
+    """Create Karnaugh Map objects which can be solved and manipulated.
+    Supported characters:
+        Any case is supported
+        or equivalents: |, ||, +, v
+        and equivalents: &, &&, *, ^
+        not equivalents: !, ~, ¬
+
+    Functions:
+
+        KarnaughMapObject.create_map(tot_input=None, expression=None) -> (bool) success
+        KarnaughMapObject.print(object, file) -> (None)
+        KarnaughMapObject.to_string(object, file) -> (str) reader-friendly table
+        KarnaughMap.get_tot_variables(expression: str) -> (Union[int, None]) total number of variables
+        KarnaughMapObject.solve_map(self: object) -> (str) simplified binary logic representation of map
+
+    GLOBAL static variables:
+
+        SINGLE  - headings for one variable
+        DOUBLE  - headings for two variables
+        TRIPLE  - headings for three variables
+        VALUES  - pairings for a whole table (index=number of variable)
+        LETTERS - letters than can be used
+
+    Class variables:
+
+        self.tot_input = None     - total number of variables in the expression (used for table dimensions)
+        self.expression = None    - unsimplified expression
+        self.valid_symbols = None - list of valid symbols that can be used
+        self.debug = debug        - debug mode (enables some prints)
+        self.table = []           - the table (can also get access through __repr__)
+        self.result = ""          - the simplified expression
+        self.raise_error = True   - whether to raise errors or just print them
+
+    Other data:
+
+        Order of operations: BNAO
+        Only tested up to 4 variables
+    """
     def __init__(self: _App, master: Tk) -> None:
         self.kmap = KarnaughMap(raise_error=False, debug=False)
         self.solution = ""
